@@ -1,14 +1,77 @@
-import datetime
+import os, datetime, logging
 from inspect import getframeinfo, stack
-from typing import List
+from typing import List, Optional
 import requests, json
 from ddd_objects.infrastructure.ao import exception_class_dec
 from ddd_objects.domain.exception import return_codes
-from ddd_objects.lib import Logger as _Logger
 from .do import LogItemDO, LogRecordDO
 
-logger = _Logger()
-logger.set_labels(file_name=__file__)
+
+class LocalLogger:
+    def __init__(self, name:Optional[str]=None, log_dir='/tmp/log') -> None:
+        if name is None:
+            name = 'root'
+        self.logger = logging.getLogger(name)
+        self.logger.setLevel(logging.DEBUG)
+        if not os.path.exists(log_dir):
+            os.makedirs(log_dir)
+        info_file_handler = logging.FileHandler(
+            os.path.join(os.path.join(log_dir, f'{name}_info.log'))
+        ) 
+        debug_file_handler = logging.FileHandler(
+            os.path.join(os.path.join(log_dir, f'{name}_debug.log'))
+        )
+        print_handler = logging.StreamHandler()
+        info_file_handler.setLevel(logging.INFO)
+        debug_file_handler.setLevel(logging.DEBUG)
+        print_handler.setLevel(logging.WARNING)
+        print_handler.set_name('print')
+        info_file_handler.set_name('info_file')
+        debug_file_handler.set_name('debug_file')
+        handler_names = [h.name for h in self.logger.handlers]
+        
+        if 'info_file' not in handler_names:
+            self.logger.addHandler(info_file_handler)
+        if 'debug_file' not in handler_names:
+            self.logger.addHandler(debug_file_handler)
+        if 'print' not in handler_names:
+            self.logger.addHandler(print_handler)
+        
+
+    def _get_header(self, msg_type:str):
+        date = datetime.datetime.utcnow().isoformat()
+        caller = getframeinfo(stack()[2][0])
+        line_num = caller.lineno
+        fn = caller.filename
+        fn = os.path.basename(fn)
+        format_str = f'[{msg_type.upper()}]{date}-{fn}-{line_num}'
+        return f'{format_str:<70}'
+
+    def debug(self, msg, *kargs, **kwargs):
+        header = self._get_header('debug')
+        msg = header+msg
+        self.logger.debug(msg, *kargs, **kwargs)
+
+    def info(self, msg, *kargs, **kwargs):
+        header = self._get_header('info')
+        msg = header+msg
+        self.logger.info(msg, *kargs, **kwargs)
+
+    def warning(self, msg, *kargs, **kwargs):
+        header = self._get_header('warning')
+        msg = header+msg
+        self.logger.warning(msg, *kargs, **kwargs)
+
+    def error(self, msg, *kargs, **kwargs):
+        header = self._get_header('error')
+        msg = header+msg
+        self.logger.error(msg, *kargs, **kwargs)
+
+    def critical(self, msg, *kargs, **kwargs):
+        header = self._get_header('critical')
+        msg = header+msg
+        self.logger.critical(msg, *kargs, **kwargs)
+
 class LogController:
     def __init__(self, ip: str=None, port: int=None) -> None:
         if port is None:
@@ -16,6 +79,7 @@ class LogController:
         if ip is None:
             ip = 'log-control-svc.system-service.svc.cluster.local'
         self.url = f"http://{ip}:{port}"
+        self.logger = LocalLogger()
 
     def _check_error(self, status_code, info):
         if status_code>299:
@@ -25,7 +89,7 @@ class LogController:
             else:
                 return_code = info['detail']['return_code']
                 error_info = info['detail']['error_info']
-            logger.error(f'Error detected by log-control-ao:\nreturn code: {return_code}\n'
+            self.logger.error(f'Error detected by log-control-ao:\nreturn code: {return_code}\n'
                 f'error info: {error_info}')
 
     @exception_class_dec(max_try=1)
@@ -76,6 +140,7 @@ class Logger:
         self.keywords = keywords
         self.controller = LogController(controller_ip, controller_port)
         self.combine_keywords = combine_keywords
+        self.logger = LocalLogger(domain)
 
     def _send_record(
         self, 
@@ -129,7 +194,7 @@ class Logger:
         combine_keywords=None,
     ):
         if self.local:
-            logger.info(content)
+            self.logger.info(content)
         return self._send_record(content, 'info', domain, location, labels, keywords, combine_keywords)
 
     def error(
@@ -142,6 +207,6 @@ class Logger:
         combine_keywords=None,
     ):
         if self.local:
-            logger.error(content)
+            self.logger.error(content)
         return self._send_record(content, 'error', domain, location, labels, keywords, combine_keywords)
 
