@@ -5,10 +5,12 @@ class LogRecordDO(BaseModel):
     log_type: str
     log_domain: str
     log_location: str
+    log_line: int
     log_inhalt: str
     creation_time: str
     log_label: List[str]=[]
     log_keywords: List[str]=[]
+    combine_keywords: bool = False
 
 class LogItemDO(BaseModel):
     id: str
